#include <QApplication>

#include "mainwindow.h"
// #include "mapwindow.h"

int main(int argc, char *argv[]) {
    QApplication app(argc, argv);

    app.setOrganizationName("Crochik");
    app.setApplicationName("GeePS");

    MainWindow wnd;
    // MapWindow wnd;
    // app.m_pMainWindow = &wnd;
    wnd.show();

    return app.exec();
}
